gt_description = "Source Logic Tree v8"


logic_tree_permutations = [
    [
        {
            "tag": "Final SLT for TAG Workshop",
            "weight": 1.0,
            "permute": [
                {
                    "group": "Hik",
                    "members": [
                        {
                            "tag": "Hik TL, N16.5, b0.95, C4, s1",
                            "weight": 0.4,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwMzM5MjI=",
                            "bg_id": "RmlsZToxMzA3MzQ=",
                        },
                        {
                            "tag": "Hik TL, N21.5, b1.097, C4, s1",
                            "weight": 0.6,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwMzM5MjE=",
                            "bg_id": "RmlsZToxMzA3NDA=",
                        },
                    ],
                },
                {
                    "group": "PUY",
                    "members": [
                        {
                            "tag": "Puy 0.7, N4.6, b0.902, C4, s1",
                            "weight": 1.0,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjExODcyMw==",
                            "bg_id": "RmlsZToxMzA3NTQ=",
                        },
                    ],
                },
                {
                    "group": "CRU",
                    "members": [
                        {
                            "tag": "geodetic, TI, N2.7, b0.823 C4.2 s1",
                            "weight": 0.35,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEyMDkxMQ==",
                            "bg_id": "RmlsZToxMzA3MTA=",
                        },
                        {
                            "tag": "geodetic, TI, N3.4, b0.959 C4.2 s1",
                            "weight": 0.65,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEyMDkwNg==",
                            "bg_id": "RmlsZToxMzA3MTk=",
                        },
                    ],
                },
                {
                    "group": "SLAB",
                    "members": [
                        {"tag": "slab-uniform-1depth-rates", "weight": 1.0, "inv_id": "", "bg_id": "RmlsZToxMjEwMzM="}
                    ],
                },
            ],
        }
    ]
]
