gt_description = "Sample Large Source Logic Tree "

logic_tree_permutations = [
    [
        {
            "tag": "Geologic",
            "weight": 1.0,
            "permute": [
                {
                    "group": "Hik",
                    "members": [
                        {
                            "tag": "hiktlck, b0.979, C3.9, s0.78",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODA3NQ==",
                            "bg_id": "RmlsZToxMDY1MjU=",
                        },
                        {
                            "tag": "hiktlck, b0.979, C3.9, s1",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODA4Mw==",
                            "bg_id": "RmlsZToxMDY1MzA=",
                        },
                        {
                            "tag": "hiktlck, b0.979, C3.9, s1.22",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODA5MA==",
                            "bg_id": "RmlsZToxMDY1Mjg=",
                        },
                        {
                            "tag": "hiktlck, b0.979, C3.9, s1.87",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODA3OA==",
                            "bg_id": "RmlsZToxMDY1Mjg=",
                        },
                        {
                            "tag": "hiktcrp, b0.979, C3.9, s1",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODA5NQ==",
                            "bg_id": "RmlsZToxMDY1Mjk=",
                        },
                        {
                            "tag": "hiktcrp, b1.101, C4.1, s1",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODE5Ng==",
                            "bg_id": "RmlsZToxMDY1NDA=",
                        },
                        {
                            "tag": "hiktcrp, b1.101, C4.1, s0.78",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODE5MQ==",
                            "bg_id": "RmlsZToxMDY1MzM=",
                        },
                        {
                            "tag": "hiktcrp, b1.101, C4.1, s1.22",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODIwMA==",
                            "bg_id": "RmlsZToxMDY1Mzg=",
                        },
                        {
                            "tag": "hiktcrp, b1.101, C4.1, s1.87",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODE5Mg==",
                            "bg_id": "RmlsZToxMDY1Mzg=",
                        },
                        {
                            "tag": "hiktlck, b1.101, C4.1, s1",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODEwMw==",
                            "bg_id": "RmlsZToxMDY1Mzk=",
                        },
                        {
                            "tag": "hiktcrp, b1.211, C4.1, s0.78",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODE5Nw==",
                            "bg_id": "RmlsZToxMDY1MzE=",
                        },
                        {
                            "tag": "hiktcrp, b1.211, C4.1, s1",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODE5OQ==",
                            "bg_id": "RmlsZToxMDY1MjQ=",
                        },
                        {
                            "tag": "hiktcrp, b1.211, C4.1, s1.22",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODE5MA==",
                            "bg_id": "RmlsZToxMDY1MzY=",
                        },
                        {
                            "tag": "hiktcrp, b1.211, C4.1, s1.87",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODE5Mw==",
                            "bg_id": "RmlsZToxMDY1MzY=",
                        },
                        {
                            "tag": "hiktcrp, b1.211, C4.1, s1",
                            "weight": 0.0666666666666667,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODE5OQ==",
                            "bg_id": "RmlsZToxMDY1MjQ=",
                        },
                    ],
                },
                {
                    "group": "PUY",
                    "members": [
                        {
                            "tag": "puy, b0.791, C3.9, s0.57",
                            "weight": 0.111111111111111,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODI3MA==",
                            "bg_id": "RmlsZToxMDY1NDg=",
                        },
                        {
                            "tag": "puy, b0.791, C3.9, s1",
                            "weight": 0.111111111111111,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODI4NQ==",
                            "bg_id": "RmlsZToxMDY1NTQ=",
                        },
                        {
                            "tag": "puy, b0.791, C3.9, s1.43",
                            "weight": 0.111111111111111,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODI3OA==",
                            "bg_id": "RmlsZToxMDY1NDE=",
                        },
                        {
                            "tag": "puy, b0.882, C4, s1",
                            "weight": 0.111111111111111,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODIzOQ==",
                            "bg_id": "RmlsZToxMDY1NzA=",
                        },
                        {
                            "tag": "puy, b0.882, C4, s0.57",
                            "weight": 0.111111111111111,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODI0Ng==",
                            "bg_id": "RmlsZToxMDY1NjE=",
                        },
                        {
                            "tag": "puy, b0.882, C4, s1.43",
                            "weight": 0.111111111111111,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODI0OQ==",
                            "bg_id": "RmlsZToxMDY1NTI=",
                        },
                        {
                            "tag": "puy, b1.064, C4.1, s0.57",
                            "weight": 0.111111111111111,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODI5Mw==",
                            "bg_id": "RmlsZToxMDY1NTg=",
                        },
                        {
                            "tag": "puy, b1.064, C4.1, s1",
                            "weight": 0.111111111111111,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODI4Mg==",
                            "bg_id": "RmlsZToxMDY1NDQ=",
                        },
                        {
                            "tag": "puy, b1.064, C4.1, s1.43",
                            "weight": 0.111111111111111,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODI3NQ==",
                            "bg_id": "RmlsZToxMDY1NjU=",
                        },
                    ],
                },
                {
                    "group": "CRU",
                    "members": [
                        {
                            "tag": "Cru_geol, b0.849, C4.1, s0.53",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODMzNw==",
                            "bg_id": "RmlsZToxMDY1NDc=",
                        },
                        {
                            "tag": "Cru_geol, b0.849, C4.1, s0.66",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODM0MQ==",
                            "bg_id": "RmlsZToxMDY1Njg=",
                        },
                        {
                            "tag": "Cru_geol, b0.849, C4.1, s1",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODMzNA==",
                            "bg_id": "RmlsZToxMDY1NTM=",
                        },
                        {
                            "tag": "Cru_geol, b0.849, C4.1, s1.47",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODM0MA==",
                            "bg_id": "RmlsZToxMDY1NDI=",
                        },
                        {
                            "tag": "Cru_geol, b0.849, C4.1, s1.61",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODMzMg==",
                            "bg_id": "RmlsZToxMDY1NjQ=",
                        },
                        {
                            "tag": "Cru_geol, b0.952, C4.2, s1",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODMyMg==",
                            "bg_id": "RmlsZToxMDY1Njk=",
                        },
                        {
                            "tag": "Cru_geol, b0.952, C4.2, s0.53",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODMyNA==",
                            "bg_id": "RmlsZToxMDY1NjI=",
                        },
                        {
                            "tag": "Cru_geol, b0.952, C4.2, s0.66",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODMyMA==",
                            "bg_id": "RmlsZToxMDY1NjA=",
                        },
                        {
                            "tag": "Cru_geol, b0.952, C4.2, s1.47",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODMyNg==",
                            "bg_id": "RmlsZToxMDY1NTE=",
                        },
                        {
                            "tag": "Cru_geol, b0.952, C4.2, s1.61",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODMzMA==",
                            "bg_id": "RmlsZToxMDY1NDk=",
                        },
                        {
                            "tag": "Cru_geol, b1.06, C4.3, s0.53",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODM0Ng==",
                            "bg_id": "RmlsZToxMDY1NTc=",
                        },
                        {
                            "tag": "Cru_geol, b1.06, C4.3, s0.66",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODM0NQ==",
                            "bg_id": "RmlsZToxMDY1NTY=",
                        },
                        {
                            "tag": "Cru_geol, b1.06, C4.3, s1",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODM0OQ==",
                            "bg_id": "RmlsZToxMDY1NDM=",
                        },
                        {
                            "tag": "Cru_geol, b1.06, C4.3, s1.47",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODM1MA==",
                            "bg_id": "RmlsZToxMDY1NjY=",
                        },
                        {
                            "tag": "Cru_geol, b1.06, C4.3, s1.61",
                            "weight": 0.0333333333333333,
                            "inv_id": "SW52ZXJzaW9uU29sdXRpb25Ocm1sOjEwODM0OA==",
                            "bg_id": "RmlsZToxMDY1NDU=",
                        },
                    ],
                },
            ],
        }
    ]
]
